@@ -23,7 +23,7 @@ use windows::Win32::System::Threading::{
 use windows::Win32::UI::WindowsAndMessaging::{ShowWindow, SW_HIDE};
 use windows::core::{HRESULT, Error};
 
-use std::{mem, env, ptr};
+use std::{mem, ptr};
 use std::mem::MaybeUninit;
 use std::ffi::OsString;
 use std::os::windows::prelude::*;
@@ -207,10 +207,6 @@ impl PTYImpl for ConPTY {
             CloseHandle(input_read_side);
             CloseHandle(output_write_side);
 
-            if env::var_os("CI").is_some() {
-                env::set_var("CONPTY_CI", "1");
-            }
-
             let pty_process = PTYProcess::new(input_write_side, output_read_side, true);
 
             Ok(Box::new(ConPTY {
@@ -391,7 +387,7 @@ impl Drop for ConPTY {
             DeleteProcThreadAttributeList(self.startup_info.lpAttributeList);
             ClosePseudoConsole(self.handle);
 
-            if env::var_os("CI").is_none() && self.console_allocated {
+            if self.console_allocated {
                 FreeConsole();
             }
         }
